==> responsive_widgets-0.1.1.tar.gz: example/lib/responsive_screen.dart <==
import 'package:flutter/material.dart';
import 'package:responsive_widgets/responsive_widgets.dart';

class ResponsiveScreen extends StatefulWidget {
  ResponsiveScreen({Key key}) : super(key: key);

  _ResponsiveScreenState createState() => _ResponsiveScreenState();
}

class _ResponsiveScreenState extends State<ResponsiveScreen> {
  @override
  Widget build(BuildContext context) {
    ResponsiveWidgets().init(context,
        referenceHeight: 1920,
        referenceWidth: 1080,
        referenceShortestSide: 360);

    return Scaffold(
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(getSizeByDp(50)),
        child: AppBar(
          title: TextResponsive('Responsive page'),
          centerTitle: true,
        ),
      ),
      body: Center(
        child: Container(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            children: <Widget>[
              TextResponsive('Plugin example app'),
              ContainerResponsive(
                height: 100,
                width: 200,
                color: Colors.green,
              ),
              RaisedButtonResponsive(
                onPressed: () {},
              ),
              IconResponsive(Icons.ac_unit),
              IconButtonResponsive(
                onPressed: () {},
                icon: Icon(Icons.ac_unit),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> responsive_widgets-0.1.10.tar.gz: example/lib/responsive_screen.dart <==
import 'package:flutter/material.dart';
import 'package:responsive_widgets/responsive_widgets.dart';

class ResponsiveScreen extends StatefulWidget {
  ResponsiveScreen({Key key}) : super(key: key);

  _ResponsiveScreenState createState() => _ResponsiveScreenState();
}

class _ResponsiveScreenState extends State<ResponsiveScreen> {
  @override
  Widget build(BuildContext context) {
    ResponsiveWidgets().init(context,
        referenceHeight: 1920,
        referenceWidth: 1080,
        referenceShortestSide: 360);

    return Scaffold(
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(ResponsiveWidgets.getSize(50)),
        child: AppBar(
          title: TextResponsive('Responsive page'),
          centerTitle: true,
        ),
      ),
      body: Center(
        child: Container(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            children: <Widget>[
              TextResponsive('Plugin example app'),
              ContainerResponsive(
                height: 100,
                width: 200,
                color: Colors.green,
              ),
              RaisedButtonResponsive(
                onPressed: () {},
              ),
              IconResponsive(Icons.ac_unit),
              IconButtonResponsive(
                onPressed: () {},
                icon: Icon(Icons.ac_unit),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
